# geotils library

Description missing    

## Citation

If you use this software in your work, please cite our [paper](https://dl.acm.org/doi/10.1145/3557915.3560953):
```bibtex
@inproceedings{geotils_2024,
}
```

## Contributing

This project welcomes contributions and suggestions. If you would like to submit a pull request, check [Contribution Guide](https://github.com/sindresorhus/awesome/blob/main/contributing.md). 


## Contact
Feel free to reach to us via below link or through aghandour at cnrs.edu.lb:
https://geogroup.ai/#contact